@@ -17,52 +17,52 @@ caption<-function (x)
 
 options(digits=4)
 
-## replace cyan in rainbow(4) with darkgreen
-colors2<-c("#FF0000", "#80FF00", "darkgreen", "#8000FF")
-
-
 # ---------------------------------------------------------------- #
 # Data sets
 
 data(aq.trans)
+head2(aq.trans)
+years<-unique(aq.trans$year)
+
+# ---------------------------------------------------------------- #
+# Fillmore stage vectors 
+
+sv<-table(aq.trans$stage, aq.trans$year)
+
+## totals
+addmargins(sv)
+
+## mean stage vector
+round(apply(sv, 1, mean),0)
 
 
+stage.vector.plot(sv[-1,], prop=FALSE, col=rainbow(4),
+     ylab = "Total number of plants",
+     main = "Fillmore Canyon stage vectors")
 
-years<-1996:2003
+### plot proportions
+
+op<-par(mar=c(5,4,2,7), xpd=TRUE)
+x<-barplot(prop.table(sv[-1,],2), las=1,
+xlab="Year", ylab="Proportion in stage class", main="Fillmore Canyon",
+col=rainbow(4), ylim=c(0,1), xaxt='n', space=.5)
+box()
+yrs<-substr(colnames(sv),3,4)
+axis(1,x, yrs)
+## draw outside plot boundaries
+
+legend(13,0.7, rev(rownames(sv)[-1]), fill=rev(rainbow(4)))
+par(op)
 
 
 # ---------------------------------------------------------------- #
-# Fillmore stage vector and plot
-
-## assign stages....
-
-sv.fill <- table(aq.trans$stage, aq.trans$year)
-
-rbind(sv.fill, TOTAL=apply(sv.fill, 2,sum))
-
-## mean vector
-round(apply(sv.fill, 1, mean),0)
-
-## remove seed bank seeds
-stage.vector.plot(sv.fill[-1,], prop=FALSE, ylab = "Total number of plants", 
-    main = "Fillmore Canyon stage vectors")
-
-
-
-
-# ---------------------------------------------------------------- #
-# DENISTY plots at Fillmore Canyon (using 1 meter square plots here-actual density in columbine.plots.data)
+# DENISTY plots at Fillmore Canyon (using 1 meter square plots)
 
 a<-ftable( aq.trans$plot, aq.trans$stage, aq.trans$year)
-
 dim(a)
 ## PLOT four stage classes: recruits, small and large veg, flowering plants
-
 op<-par(mfrow=c(2,2), mar=c(4, 4, 2 , 2) , oma=c(1,1,2,0))
-
 fstages<-c("Recruits", "Small vegetative", "Large vegetative", "Flowering plants")
-
-## skip seeds
 for (i in 2:5)
 {
    x<-a[seq(i,50,5),]   
@@ -73,26 +73,19 @@ for (i in 2:5)
    }
 }
 title(expression(paste("Plant density in 10 demography plots (", m^-2, ")")), outer=TRUE)
-
-
 par(op)
 
 
-
 # ---------------------------------------------------------------- #
 # BUILD a projection matrix for Aquilegia
 
-
 ## 1.  get transitions for a single projection interval (1996-1997)
-
 x<-subset(aq.trans, year==1996)
 
-## 2. number of recruits in 1997 
-
-recruits<- sv.fill["recruit", "1997"]
+## 2. count number of recruits in 1997 
+recruits<- sv["recruit", "1997"]
 
 ## 3.  Use aq.matrix() to build matrix 
-
 aq.96<- aq.matrix(x, recruits)
 aq.96
 caption("1996-1997 projection matrix and vectors from aq.matrix")
@@ -102,17 +95,16 @@ caption("1996-1997 projection matrix and vectors from aq.matrix")
 #  Population projections
 
 p<-pop.projection(aq.96$A, aq.96$n)
-
 p
-
 ## exclude seeds
-stage.vector.plot(  p$stage.vectors[-1,1:10], xlab="Years after 1996", main="Convergence to stable stage distribution")   
+stage.vector.plot(  p$stage.vectors[-1,1:10], col=rainbow(4), prop=FALSE,
+   xlab="Years after 1996", main="Stage vector projections", log='y')
+
 
 # ---------------------------------------------------------------- #
 #  Eigenvalues and vectors
 
 eig.96<- eigen.analysis(aq.96$A)
-
 eig.96
 
 
@@ -122,18 +114,33 @@ box()
 
 
 ymax<-max(eig.96$repro.value)*1.25
-barplot(eig.96$repro.value, col="green", ylim=c(0,  ymax ), xpd=FALSE, ylab="Reproductive value", xlab="Stage Class", main="Reproductive values from 96-97 matrix")
+barplot(eig.96$repro.value, col="green", ylim=c(0,  ymax ), xpd=FALSE, ylab="Reproductive value", xlab="Stage Class", main="Reproductive values")
 box()
 
-
 eig.96$elasticities
 
-## no 3-d barplot like Matlab  -- use heatmap?   image uses heat.colors(12) by default to create heat-spectrum (red to white) -  need to add color bar?
+## 0's with log-scale will cause warnings at end of demo 
+eig.96$elasticities[eig.96$elasticities==0]<-NA
 
-op<-par(cex.main=.8) 
-heatmap(eig.96$elasticities[order(5:1),], Rowv=NA, Colv=NA, scale="none", margin=c(8,8), ylab="Fate", xlab="Stage", main="Elasticities from 96-97 matrix", col=rev(heat.colors(24)))
+op<-par(mar=c(5,6,4,1))
+matplot(t(eig.96$elasticities), log='y', yaxt='n',
+xlab="Stage at time t",  ylab="",
+main="Elasticity matrix")
+axis(2, at=c(0.005, 0.01, 0.02, 0.05, 0.10, 0.20), labels=c("0.005", "0.01", "0.02", "0.05", "0.1", "0.2" ),
+las=1)
+legend(2,.02, colnames(eig.96$elasticities), pch=as.character(1:5), col=1:5, title="Fate at time t+1")
+mtext("Elasticity (log scale)",2, line=4)
 par(op)
 
+eig.96$sensitivities
+eig.96$sensitivities[eig.96$sensitivities==0]<-NA
+
+matplot(t(eig.96$sensitivities), log='y', yaxt='n',
+xlab="Stage at time t",  ylab="",
+main="Sensitivity matrix")
+axis(2, at=c( 0.001, 0.01,  0.1, 1), labels=expression(10^-3, 10^-2, 10^-1, 10^0) , las=1)
+legend(2,.01, colnames(eig.96$sensitivities), pch=as.character(1:5), col=1:5, title="Fate at time t+1")
+mtext("Sensitivity (log scale)",2, line=4)
 
 
 # ---------------------------------------------------------------- #
@@ -150,7 +157,6 @@ aq.96.boot<-boot.transitions(y, 200, add=c(1,1, aq.96$seed.survival, 2,1, aq.96$
 # calculate confidence intervals using quantile() or perc.ci and other methods in boot package
 
 ci<- quantile(aq.96.boot$lambda, c(0.025,0.975) )
-
 aq.96$lambda
 ci
 
@@ -170,29 +176,24 @@ n<-length(years)
 fill1.all<- vector("list", n)
 names(fill1.all)<-years
 
-
-
 fill1<-matrix(numeric(length(years)*5), nrow=n, dimnames=list(years, c("lambda", "seed.new", "seed.b0", "seed.b1", "rec.rate") )) 
-
 for (s.year in years)
 {
    i<-s.year- (years[1]-1)   ## index for list starting at 1
-   x<-aq.matrix(subset(aq.trans, year==s.year), sv.fill['recruit', as.character(s.year+1)] )
+   x<-aq.matrix(subset(aq.trans, year==s.year), sv['recruit', as.character(s.year+1)] )
    fill1[i,] <- c(x$lambda, x$seeds.from.plants, x$seed.bank, x$n1[1], x$recruitment.rate)
    fill1.all[[i]]<-x
  }
-
 fill1.all[["1997"]]
 fill1
 
-
 plot(rownames(fill1), fill1[,1], type='b', ylim=c(0,1.4), xlab="Year", ylab="Growth rate" , main=paste("Population growth rate using constant \nseed bank size and seed survival rate"), col="red", pch=16, las=1)
  abline(h=1, lty=3)
 
 
 
 # ---------------------------------------------------------------- #
-# VITAL RATES and matrix elements....
+#  Projection matrix elements....
 
 
 ## list only projection matrices - will be used later for stochastic growth
@@ -208,23 +209,7 @@ fill.vr<-rbind(fill.vr, mean=apply(fill.vr, 2, mean), var=apply(fill.vr, 2, var)
 # TABLE using years as columns and ignoring empty elements
 t( fill.vr[,c(1:2, 8,10,13:15,18:25)] )
 
-caption("Estimated projection matrix elements for 11 years")
-
-##  Matrix element Correlations  
-
-vr2<-fill.vr[1:n,c(1:2, 8,10,13:15,18:25)]
-
-# turn off warning standard deviation is zero in: cor(x, y, na.method, method == "kendall")
-options(warn=-1)
-z<-cor(vr2)
-options(warn=0)
-
-z[upper.tri(z)]<-NA
-
-z
-
-## plot using heatmap?
-heatmap(z[order(15:1),], Rowv=NA, Colv=NA, scale="none", main="Correlation matrix 96-02", xlab="Matrix element", col=rev(heat.colors(24)))
+caption("Annual, mean and variance of projection matrix elements (1996-2002)")
 
 
 # ---------------------------------------------------------------- #
@@ -281,7 +266,7 @@ for (s.year in years)
    for (i in seq(0,100,10))
    {
       x<-aq.matrix(subset(aq.trans, year==s.year),
-                   sv.fill['recruit',as.character(s.year+1)], seed.survival=i/100)
+                   sv['recruit',as.character(s.year+1)], seed.survival=i/100)
       fill.seed.surv[[z]][(i+10)/10,]<- c(i/100, x$lambda, x$n1[1])
    }
 }
@@ -317,7 +302,7 @@ text(-.08, y, y.abbr, pos=4)
    for (i in seq(1000,25000,1000))
    {
       x<-aq.matrix(subset(aq.trans,  year==1997),
-                   sv.fill['recruit','1998'], seed.bank.size= i  )
+                   sv['recruit','1998'], seed.bank.size= i  )
       fill.seed.97[i/1000,]<- c(i, x$lambda )
    }
 
@@ -330,7 +315,7 @@ plot(fill.seed.97[,1], fill.seed.97[,2],
 # ---------------------------------------------------------------- #
 #  STOCHASTIC growth rates  -this will take a while
 
-eigen.analysis(A.mean)$lambda
+eigen.analysis(A.mean)$lambda1
 
 
 stoch.growth.rate(fill.A)
@@ -339,7 +324,7 @@ stoch.growth.rate(fill.A)
 # ---------------------------------------------------------------- #
 #  Stochastic population sizes
 
-sv.mean<-c(seed=10000, round(apply(sv.fill, 1, mean),0)[-1])
+sv.mean<-c(seed=10000, round(apply(sv, 1, mean),0)[-1])
 
 
 ##  set 2000 above-ground plants as max density in 15 m2 plots...
@@ -357,16 +342,9 @@ abline(v=sum(sv.mean[-1]), lty=2)
 
 aq.ex.seed<-stoch.quasi.ext(fill.A, n0=sv.mean, Nx=1, nreps=500, sumweight=c(0,1,1,1,1))
 
-
-plot(aq.ex.seed[,1], xlab="Years", ylab="Quasi-extinction probability", type="n", ylim=c(0,max(aq.ex.seed)), main=paste("Time to reach a quasi-extinction threshold\nof 1 above-ground individual using 96-02 matrices"))
-for(i in 1:dim(aq.ex.seed)[2])
-  {
-    lines(aq.ex.seed[,i], col=rainbow(dim(aq.ex.seed)[2])[i])
-  }
-
-
-
-
+matplot(aq.ex.seed, xlab="Years", ylab="Quasi-extinction probability", type="l",
+     main=paste("Time to reach a quasi-extinction threshold
+of 1 above-ground individual"))
 
 
 par(opar)
